function MigrationFlow() {
    
  // Name for the visualisation to appear in the menu bar.
  // Data Source: https://stats.oecd.org/Index.aspx?DataSetCode=MIG
  this.name = 'World Migration Inflow ';
  this.id = 'migration-Flow';
  // Property to represent whether data has been loaded.
  this.loaded = false;

  this.preload = function() {
      var self = this;
      this.data = loadTable(
        './data/migration/MigrationData.csv', 'csv', 'header',
        // Callback function to set the value
        // this.loaded to true.
        function(table) {
          self.loaded = true;
        });     

    };
    
    this.setup = function() 
    {
      if (!this.loaded) 
      {
        console.log('Data not yet loaded');
        return;
      }
  
      // Create a select DOM element.
      this.select = createSelect();
      this.select.position(350, 40);
  
      // Fill the options with all year .
      var year = this.data.columns;
      // First entry is empty.
      for (let i = 2; i < year.length; i++) 
      {
        this.select.option(year[i]);
      }
    };  
  
 
  this.draw = function()
  {  
    if (!this.loaded) {
      console.log('Data not yet loaded');
      return;
    }
var yearsData = this.select.value();
var yearPrev = yearsData - 1;
// Get the column of raw data for yearsData.
var col = this.data.getColumn(yearsData);
//var col1 = this.data.getColumn(yearPrev); its supposed to pick the previous year data but it causes a bug on plotting 
var col1 = this.data.getColumn(yearsData);
    
// Convert all data strings to numbers.
col = stringsToNumbers(col);
col1 = stringsToNumbers(col1);

// labels from the table (the first item of each row).
var labels = this.data.getColumn(0);

// Colour to use for each category.
var colors = ['blue', 'red', 'green', 'pink', 'purple', 'yellow','black','grey','skyblue','maroon'];

// Key to use to determine bar size
var key1 = max(col);
var key2 = max(col1);

  // Upper heading of current and previous year
  textSize(18);
  fill('black');
  text(yearPrev, width *0.25, 20);
  text(yearsData, width *0.75, 20);

  var position = 25;
  var bar_heightarea = height - 100;
  var bar_height = bar_heightarea / col.length;
  var fontsize = bar_height / bar_heightarea * 100;
   

    for(i = 0; i < col.length; i++)
    {      
      
        fill(colors[i]);
        stroke('white');
        rect(width / 2 + 5,position,col[i] / key1 * 100 * 3.5,bar_height); 
        textSize(fontsize);
        fill('black');
        noStroke(0);
        text(labels[i] + ' ' + col[i], width / 2 + col[i] / key1 * 100 * 3.5 + 10,position + bar_height / 2);
        fill('red');
        stroke('white');

          if(dist(mouseX,mouseY,width / 2 + 5,position) > 2 && dist(mouseX,mouseY,width / 2 + 5,position) <= col[i]/key1 * 100 * 3.5 && mouseX >= width / 2 + 5 && mouseY <= position) 
          {
            textSize(16);
            text( col[i] + ' People Migrated to ' + labels[i], width * 0.35, 20);
          };
       
        rect((width / 2) - (col1[i]/key2 * 100 * 3.5), position,col1[i] / key2 * 100 * 3.5,bar_height); 
        textSize(fontsize);

        fill('red');
        noStroke(0);
        text(col1[i],(width / 2) - (col1[i] / key2 * 100 * 3.5) - 60,position + bar_height / 2);
        position += bar_heightarea / col.length;

    };
   
  // Lower Heading
  textSize(18);
  fill('black');
  text(this.name + '2000 - 2021', width/2 - 130, height - 50);

  } 

}
